@@ -99,7 +99,7 @@ void resetReplayerState(void)
 
 		ch = channel;
 		for (int32_t i = 0; i < song.numChannels; i++, ch++)
-			ch->status |= IS_Vol;
+			ch->status |= CS_UPDATE_VOL;
 	}
 }
 
@@ -115,7 +115,7 @@ void resetChannels(void)
 	for (int32_t i = 0; i < MAX_CHANNELS; i++, ch++)
 	{
 		ch->instrPtr = instr[0];
-		ch->status = IS_Vol;
+		ch->status = CS_UPDATE_VOL;
 		ch->oldPan = 128;
 		ch->outPan = 128;
 		ch->finalPan = 128;
@@ -308,7 +308,7 @@ void resetVolumes(channel_t *ch)
 	ch->outVol = ch->oldVol;
 	ch->outPan = ch->oldPan;
 
-	ch->status |= IS_Vol + IS_Pan + IS_QuickVol;
+	ch->status |= CS_UPDATE_VOL + CS_UPDATE_PAN + CS_USE_QUICK_VOLRAMP;
 }
 
 void triggerInstrument(channel_t *ch)
@@ -376,7 +376,7 @@ void keyOff(channel_t *ch)
 	{
 		ch->realVol = 0;
 		ch->outVol = 0;
-		ch->status |= IS_Vol + IS_QuickVol;
+		ch->status |= CS_UPDATE_VOL + CS_USE_QUICK_VOLRAMP;
 	}
 
 	if (!(ins->panEnvFlags & ENV_ENABLED)) // FT2 logic bug!
@@ -522,7 +522,7 @@ void triggerNote(uint8_t note, uint8_t efx, uint8_t efxData, channel_t *ch)
 		ch->outPeriod = ch->realPeriod = note2PeriodLUT[noteIndex];
 	}
 
-	ch->status |= IS_Period + IS_Vol + IS_Pan + IS_Trigger + IS_QuickVol;
+	ch->status |= CF_UPDATE_PERIOD + CS_UPDATE_VOL + CS_UPDATE_PAN + CS_TRIGGER_VOICE + CS_USE_QUICK_VOLRAMP;
 
 	if (efx == 9) // 9xx (Set Sample Offset)
 	{
@@ -560,7 +560,7 @@ static void finePitchSlideUp(channel_t *ch, uint8_t param)
 		ch->realPeriod = 1;
 
 	ch->outPeriod = ch->realPeriod;
-	ch->status |= IS_Period;
+	ch->status |= CF_UPDATE_PERIOD;
 }
 
 static void finePitchSlideDown(channel_t *ch, uint8_t param)
@@ -575,12 +575,12 @@ static void finePitchSlideDown(channel_t *ch, uint8_t param)
 		ch->realPeriod = 32000-1;
 
 	ch->outPeriod = ch->realPeriod;
-	ch->status |= IS_Period;
+	ch->status |= CF_UPDATE_PERIOD;
 }
 
 static void setPortamentoCtrl(channel_t *ch, uint8_t param)
 {
-	ch->portaSemitoneSlides = (param != 0);
+	ch->semitonePortaMode = (param != 0);
 }
 
 static void setVibratoCtrl(channel_t *ch, uint8_t param)
@@ -625,7 +625,7 @@ static void fineVolSlideUp(channel_t *ch, uint8_t param)
 		ch->realVol = 64;
 
 	ch->outVol = ch->realVol;
-	ch->status |= IS_Vol;
+	ch->status |= CS_UPDATE_VOL;
 }
 
 static void fineVolFineDown(channel_t *ch, uint8_t param)
@@ -640,7 +640,7 @@ static void fineVolFineDown(channel_t *ch, uint8_t param)
 		ch->realVol = 0;
 
 	ch->outVol = ch->realVol;
-	ch->status |= IS_Vol;
+	ch->status |= CS_UPDATE_VOL;
 }
 
 static void noteCut0(channel_t *ch, uint8_t param)
@@ -649,7 +649,7 @@ static void noteCut0(channel_t *ch, uint8_t param)
 	{
 		ch->realVol = 0;
 		ch->outVol = 0;
-		ch->status |= IS_Vol + IS_QuickVol;
+		ch->status |= CS_UPDATE_VOL + CS_USE_QUICK_VOLRAMP;
 	}
 }
 
@@ -754,7 +754,7 @@ static void setGlobalVolume(channel_t *ch, uint8_t param)
 	// update all voice volumes
 	channel_t *c = channel;
 	for (int32_t i = 0; i < song.numChannels; i++, c++)
-		c->status |= IS_Vol;
+		c->status |= CS_UPDATE_VOL;
 
 	(void)ch;
 }
@@ -973,7 +973,7 @@ static void v_SetVolume(channel_t *ch, uint8_t *volColumnData)
 		*volColumnData = 64;
 
 	ch->outVol = ch->realVol = *volColumnData;
-	ch->status |= IS_Vol + IS_QuickVol;
+	ch->status |= CS_UPDATE_VOL + CS_USE_QUICK_VOLRAMP;
 }
 
 static void v_FineVolSlideDown(channel_t *ch, uint8_t *volColumnData)
@@ -983,7 +983,7 @@ static void v_FineVolSlideDown(channel_t *ch, uint8_t *volColumnData)
 		*volColumnData = 0;
 
 	ch->outVol = ch->realVol = *volColumnData;
-	ch->status |= IS_Vol;
+	ch->status |= CS_UPDATE_VOL;
 }
 
 static void v_FineVolSlideUp(channel_t *ch, uint8_t *volColumnData)
@@ -993,7 +993,7 @@ static void v_FineVolSlideUp(channel_t *ch, uint8_t *volColumnData)
 		*volColumnData = 64;
 
 	ch->outVol = ch->realVol = *volColumnData;
-	ch->status |= IS_Vol;
+	ch->status |= CS_UPDATE_VOL;
 }
 
 static void v_SetPan(channel_t *ch, uint8_t *volColumnData)
@@ -1001,7 +1001,7 @@ static void v_SetPan(channel_t *ch, uint8_t *volColumnData)
 	*volColumnData <<= 4;
 
 	ch->outPan = *volColumnData;
-	ch->status |= IS_Pan;
+	ch->status |= CS_UPDATE_PAN;
 }
 
 // -- non-tick-zero volume column effects --
@@ -1013,7 +1013,7 @@ static void v_VolSlideDown(channel_t *ch)
 		newVol = 0;
 
 	ch->outVol = ch->realVol = newVol;
-	ch->status |= IS_Vol;
+	ch->status |= CS_UPDATE_VOL;
 }
 
 static void v_VolSlideUp(channel_t *ch)
@@ -1023,7 +1023,7 @@ static void v_VolSlideUp(channel_t *ch)
 		newVol = 64;
 
 	ch->outVol = ch->realVol = newVol;
-	ch->status |= IS_Vol;
+	ch->status |= CS_UPDATE_VOL;
 }
 
 static void v_Vibrato(channel_t *ch)
@@ -1042,7 +1042,7 @@ static void v_PanSlideLeft(channel_t *ch)
 		tmp16 = 0;
 
 	ch->outPan = (uint8_t)tmp16;
-	ch->status |= IS_Pan;
+	ch->status |= CS_UPDATE_PAN;
 }
 
 static void v_PanSlideRight(channel_t *ch)
@@ -1052,7 +1052,7 @@ static void v_PanSlideRight(channel_t *ch)
 		tmp16 = 255;
 
 	ch->outPan = (uint8_t)tmp16;
-	ch->status |= IS_Pan;
+	ch->status |= CS_UPDATE_PAN;
 }
 
 static void v_Portamento(channel_t *ch)
@@ -1092,7 +1092,7 @@ static const volColumnEfxRoutine2 VJumpTab_TickZero[16] =
 static void setPan(channel_t *ch, uint8_t param)
 {
 	ch->outPan = param;
-	ch->status |= IS_Pan;
+	ch->status |= CS_UPDATE_PAN;
 }
 
 static void setVol(channel_t *ch, uint8_t param)
@@ -1101,7 +1101,7 @@ static void setVol(channel_t *ch, uint8_t param)
 		param = 64;
 
 	ch->outVol = ch->realVol = param;
-	ch->status |= IS_Vol + IS_QuickVol;
+	ch->status |= CS_UPDATE_VOL + CS_USE_QUICK_VOLRAMP;
 }
 
 static void extraFinePitchSlide(channel_t *ch, uint8_t param)
@@ -1123,7 +1123,7 @@ static void extraFinePitchSlide(channel_t *ch, uint8_t param)
 			newPeriod = 1;
 
 		ch->outPeriod = ch->realPeriod = newPeriod;
-		ch->status |= IS_Period;
+		ch->status |= CF_UPDATE_PERIOD;
 	}
 	else if (slideType == 2) // slide down
 	{
@@ -1139,7 +1139,7 @@ static void extraFinePitchSlide(channel_t *ch, uint8_t param)
 			newPeriod = 32000-1;
 
 		ch->outPeriod = ch->realPeriod = newPeriod;
-		ch->status |= IS_Period;
+		ch->status |= CF_UPDATE_PERIOD;
 	}
 }
 
@@ -1280,7 +1280,7 @@ static void getNewNote(channel_t *ch, const note_t *p)
 		if (ch->efxData > 0) // we have an arpeggio running, set period back
 		{
 			ch->outPeriod = ch->realPeriod;
-			ch->status |= IS_Period;
+			ch->status |= CF_UPDATE_PERIOD;
 		}
 	}
 	else
@@ -1289,7 +1289,7 @@ static void getNewNote(channel_t *ch, const note_t *p)
 		if ((ch->efx == 4 || ch->efx == 6) && (p->efx != 4 && p->efx != 6))
 		{
 			ch->outPeriod = ch->realPeriod;
-			ch->status |= IS_Period;
+			ch->status |= CF_UPDATE_PERIOD;
 		}
 	}
 
@@ -1401,7 +1401,7 @@ void updateVolPanAutoVib(channel_t *ch)
 			}
 		}
 
-		ch->status |= IS_Vol; // always update volume, even if fadeout has reached 0
+		ch->status |= CS_UPDATE_VOL; // always update volume, even if fadeout has reached 0
 	}
 	
 	// handle volumes
@@ -1502,7 +1502,7 @@ void updateVolPanAutoVib(channel_t *ch)
 			fVol = vol * (1.0f / (64.0f * 64.0f * 32768.0f));
 			fVol *= fEnvVal * (1.0f / 64.0f); // volume envelope value
 
-			ch->status |= IS_Vol; // update mixer vol every tick when vol envelope is enabled
+			ch->status |= CS_UPDATE_VOL; // update mixer vol every tick when vol envelope is enabled
 		}
 		else
 		{
@@ -1616,7 +1616,7 @@ void updateVolPanAutoVib(channel_t *ch)
 
 		ch->finalPan = (uint8_t)CLAMP(newPan, 0, 255); // FT2 doesn't clamp the pan, but let's do it anyway
 
-		ch->status |= IS_Pan; // update pan every tick because pan envelope is enabled
+		ch->status |= CS_UPDATE_PAN; // update pan every tick because pan envelope is enabled
 	}
 	else
 	{
@@ -1683,7 +1683,7 @@ void updateVolPanAutoVib(channel_t *ch)
 #endif
 
 		ch->finalPeriod = tmpPeriod;
-		ch->status |= IS_Period;
+		ch->status |= CF_UPDATE_PERIOD;
 	}
 	else
 	{
@@ -1693,14 +1693,14 @@ void updateVolPanAutoVib(channel_t *ch)
 		if (midi.enable)
 		{
 			ch->finalPeriod -= ch->midiPitch;
-			ch->status |= IS_Period;
+			ch->status |= CF_UPDATE_PERIOD;
 		}
 #endif
 	}
 }
 
 // for arpeggio and portamento (semitone-slide mode)
-static uint16_t adjustPeriodFromNote(uint16_t period, uint8_t arpNote, channel_t *ch)
+static uint16_t period2NotePeriod(uint16_t period, uint8_t outputNoteOffset, channel_t *ch)
 {
 	int32_t tmpPeriod;
 
@@ -1727,7 +1727,7 @@ static uint16_t adjustPeriodFromNote(uint16_t period, uint8_t arpNote, channel_t
 			loPeriod = (tmpPeriod - fineTune) & ~15;
 	}
 
-	tmpPeriod = loPeriod + fineTune + (arpNote << 4);
+	tmpPeriod = loPeriod + fineTune + (outputNoteOffset << 4);
 	if (tmpPeriod >= (8*12*16+15)-1) // FT2 bug, should've been 10*12*16+16 (also notice the +2 difference)
 		tmpPeriod = (8*12*16+16)-1;
 
@@ -1763,13 +1763,13 @@ static void doVibrato(channel_t *ch)
 	else
 		ch->outPeriod = ch->realPeriod + tmpVib;
 
-	ch->status |= IS_Period;
+	ch->status |= CF_UPDATE_PERIOD;
 	ch->vibratoPos += ch->vibratoSpeed;
 }
 
 static void arpeggio(channel_t *ch, uint8_t param)
 {
-	uint8_t note;
+	uint8_t noteOffset;
 
 	const uint8_t tick = arpeggioTab[song.tick & 31];
 	if (tick == 0)
@@ -1779,14 +1779,14 @@ static void arpeggio(channel_t *ch, uint8_t param)
 	else
 	{
 		if (tick == 1)
-			note = param >> 4;
+			noteOffset = param >> 4;
 		else
-			note = param & 0x0F; // tick 2
+			noteOffset = param & 0x0F; // tick 2
 
-		ch->outPeriod = adjustPeriodFromNote(ch->realPeriod, note, ch);
+		ch->outPeriod = period2NotePeriod(ch->realPeriod, noteOffset, ch);
 	}
 
-	ch->status |= IS_Period;
+	ch->status |= CF_UPDATE_PERIOD;
 }
 
 static void pitchSlideUp(channel_t *ch, uint8_t param)
@@ -1801,7 +1801,7 @@ static void pitchSlideUp(channel_t *ch, uint8_t param)
 		ch->realPeriod = 1;
 
 	ch->outPeriod = ch->realPeriod;
-	ch->status |= IS_Period;
+	ch->status |= CF_UPDATE_PERIOD;
 }
 
 static void pitchSlideDown(channel_t *ch, uint8_t param)
@@ -1816,7 +1816,7 @@ static void pitchSlideDown(channel_t *ch, uint8_t param)
 		ch->realPeriod = 32000-1;
 
 	ch->outPeriod = ch->realPeriod;
-	ch->status |= IS_Period;
+	ch->status |= CF_UPDATE_PERIOD;
 }
 
 static void portamento(channel_t *ch, uint8_t param)
@@ -1843,12 +1843,12 @@ static void portamento(channel_t *ch, uint8_t param)
 		}
 	}
 
-	if (ch->portaSemitoneSlides)
-		ch->outPeriod = adjustPeriodFromNote(ch->realPeriod, 0, ch);
+	if (ch->semitonePortaMode)
+		ch->outPeriod = period2NotePeriod(ch->realPeriod, 0, ch);
 	else
 		ch->outPeriod = ch->realPeriod;
 
-	ch->status |= IS_Period;
+	ch->status |= CF_UPDATE_PERIOD;
 
 	(void)param;
 }
@@ -1934,7 +1934,7 @@ static void tremolo(channel_t *ch, uint8_t param)
 	}
 
 	ch->outVol = (uint8_t)tremVol;
-	ch->status |= IS_Vol;
+	ch->status |= CS_UPDATE_VOL;
 
 	ch->tremoloPos += ch->tremoloSpeed;
 }
@@ -1963,7 +1963,7 @@ static void volSlide(channel_t *ch, uint8_t param)
 	}
 
 	ch->outVol = ch->realVol = newVol;
-	ch->status |= IS_Vol;
+	ch->status |= CS_UPDATE_VOL;
 }
 
 static void globalVolSlide(channel_t *ch, uint8_t param)
@@ -1995,7 +1995,7 @@ static void globalVolSlide(channel_t *ch, uint8_t param)
 
 	channel_t *c = channel;
 	for (int32_t i = 0; i < song.numChannels; i++, c++)
-		c->status |= IS_Vol;
+		c->status |= CS_UPDATE_VOL;
 }
 
 static void keyOffCmd(channel_t *ch, uint8_t param)
@@ -2028,7 +2028,7 @@ static void panningSlide(channel_t *ch, uint8_t param)
 	}
 
 	ch->outPan = (uint8_t)newPan;
-	ch->status |= IS_Pan;
+	ch->status |= CS_UPDATE_PAN;
 }
 
 static void tremor(channel_t *ch, uint8_t param)
@@ -2058,7 +2058,7 @@ static void tremor(channel_t *ch, uint8_t param)
 
 	ch->tremorPos = tremorSign | tremorData;
 	ch->outVol = (tremorSign == 0x80) ? ch->realVol : 0;
-	ch->status |= IS_Vol + IS_QuickVol;
+	ch->status |= CS_UPDATE_VOL + CS_USE_QUICK_VOLRAMP;
 }
 
 static void retrigNote(channel_t *ch, uint8_t param)
@@ -2078,7 +2078,7 @@ static void noteCut(channel_t *ch, uint8_t param)
 	if ((uint8_t)(song.speed-song.tick) == param)
 	{
 		ch->outVol = ch->realVol = 0;
-		ch->status |= IS_Vol + IS_QuickVol;
+		ch->status |= CS_UPDATE_VOL + CS_USE_QUICK_VOLRAMP;
 	}
 }
 
@@ -3036,7 +3036,7 @@ void playSample(uint8_t chNum, uint8_t insNum, uint8_t smpNum, uint8_t note, uin
 
 	unlockAudio();
 
-	while (ch->status & IS_Trigger); // wait for sample to latch in mixer
+	while (ch->status & CS_TRIGGER_VOICE); // wait for voice to trigger in mixer
 
 	// for sampling playback line in Smp. Ed.
 	editor.curPlayInstr = editor.curInstr;
@@ -3099,7 +3099,7 @@ void playRange(uint8_t chNum, uint8_t insNum, uint8_t smpNum, uint8_t note, uint
 
 	unlockAudio();
 
-	while (ch->status & IS_Trigger); // wait for sample to latch in mixer
+	while (ch->status & CS_TRIGGER_VOICE); // wait for voice to trigger in mixer
 
 	// for sampling playback line in Smp. Ed.
 	editor.curPlayInstr = editor.curInstr;
@@ -3124,7 +3124,7 @@ void stopVoices(void)
 		ch->smpPtr = NULL;
 		ch->instrNum = 0;
 		ch->instrPtr = instr[0]; // important: set instrument pointer to instr 0 (placeholder instrument)
-		ch->status = IS_Vol;
+		ch->status = CS_UPDATE_VOL;
 		ch->realVol = 0;
 		ch->outVol = 0;
 		ch->oldVol = 0;
