@@ -6,7 +6,7 @@
 
 #define QUADRATIC_SPLINE_WIDTH 3
 #define QUADRATIC_SPLINE_PHASES 8192
-#define QUADRATIC_SPLINE_PHASES_BITS 13 // log2(QUADRATIC_SPLINE_PHASES)
+#define QUADRATIC_SPLINE_PHASES_BITS 13 /* log2(QUADRATIC_SPLINE_PHASES) */
 #define QUADRATIC_SPLINE_FRACSHIFT (MIXER_FRAC_BITS-QUADRATIC_SPLINE_PHASES_BITS)
 
 extern float *fQuadraticSplineLUT;
