@@ -35,16 +35,16 @@ bool calcScopeIntrpLUT(void)
 		const double x2 = x1 * x1; // x^2
 		const double x3 = x2 * x1; // x^3
 
-		double t1 = (-(1.0/6.0) * x3) + ( (1.0/2.0) * x2) + (-(1.0/2.0) * x1) + (1.0/6.0);
-		double t2 = ( (1.0/2.0) * x3) + (     -1.0  * x2)                     + (2.0/3.0);
-		double t3 = (-(1.0/2.0) * x3) + ( (1.0/2.0) * x2) + ( (1.0/2.0) * x1) + (1.0/6.0);
-		double t4 =   (1.0/6.0) * x3;
+		const double t1 = (x1 * -(1.0/2.0)) + (x2 * (1.0/2.0)) + (x3 * -(1.0/6.0)) + (1.0/6.0);
+		const double t2 =                     (x2 *     -1.0 ) + (x3 *  (1.0/2.0)) + (2.0/3.0);
+		const double t3 = (x1 *  (1.0/2.0)) + (x2 * (1.0/2.0)) + (x3 * -(1.0/2.0)) + (1.0/6.0);
+		const double t4 =                                         x3 *  (1.0/6.0);
 
-		// rounding here would make the scopes clip, but we clamp the scopes for another reason anyway
-		*ptr16++ = (int16_t)round(t1 * SCOPE_INTRP_SCALE);
-		*ptr16++ = (int16_t)round(t2 * SCOPE_INTRP_SCALE);
-		*ptr16++ = (int16_t)round(t3 * SCOPE_INTRP_SCALE);
-		*ptr16++ = (int16_t)round(t4 * SCOPE_INTRP_SCALE);
+		// truncate, do not round!
+		*ptr16++ = (int16_t)(t1 * SCOPE_INTRP_SCALE); // tap #1 at sample offset -1
+		*ptr16++ = (int16_t)(t2 * SCOPE_INTRP_SCALE); // tap #2 at sample offset  0 (center)
+		*ptr16++ = (int16_t)(t3 * SCOPE_INTRP_SCALE); // tap #3 at sample offset  1
+		*ptr16++ = (int16_t)(t4 * SCOPE_INTRP_SCALE); // tap #4 at sample offset  2
 	}
 
 	return true;
